# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Status(str, Enum):
    """
    Represents the status of a resource.
    """

    """
    allowed enum values
    """
    UP = 'up'
    DOWN = 'down'
    DEGRADED = 'degraded'
    UNKNOWN = 'unknown'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Status from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "esnet-iri"
VERSION = "1.0.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="ESnet implementation of the IRI api",
    author="ESnet Contact",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "ESnet implementation of the IRI api"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  &lt;img src&#x3D;\&quot;https://iri.science/images/doe-icon-old.png\&quot; height&#x3D;50 /&gt; 
    """,  # noqa: E501
    package_data={"esnet_iri": ["py.typed"]},
)


# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from esnet_iri.models.allocation_entry import AllocationEntry
from typing import Optional, Set
from typing_extensions import Self

class UserAllocation(BaseModel):
    """
    A user's allcation in a project. This allocation is a piece of the project's allocation.
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the user allocation.")
    user_id: StrictStr = Field(description="Identifier of the user receiving this allocation.")
    entries: List[AllocationEntry] = Field(description="Allocation entries describing usage and limits.")
    project_allocation_uri: StrictStr = Field(description="URI of the associated project allocation")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "user_id", "entries", "project_allocation_uri"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserAllocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "project_allocation_uri",
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in entries (list)
        _items = []
        if self.entries:
            for _item_entries in self.entries:
                if _item_entries:
                    _items.append(_item_entries.to_dict())
            _dict['entries'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserAllocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "entries": [AllocationEntry.from_dict(_item) for _item in obj["entries"]] if obj.get("entries") is not None else None,
            "project_allocation_uri": obj.get("project_allocation_uri")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class Site(BaseModel):
    """
    A physical site that hosts resources and is part of a facility.
    """ # noqa: E501
    id: StrictStr = Field(description="The unique identifier for the object. Typically a UUID or URN.")
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    last_modified: datetime = Field(description="ISO 8601 timestamp when this object was last modified.")
    short_name: Optional[StrictStr] = None
    operating_organization: Optional[StrictStr]
    country_name: Optional[StrictStr] = None
    locality_name: Optional[StrictStr] = None
    state_or_province_name: Optional[StrictStr] = None
    street_address: Optional[StrictStr] = None
    unlocode: Optional[StrictStr] = None
    altitude: Optional[Union[StrictFloat, StrictInt]] = None
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    self_uri: StrictStr = Field(description="The canonical URL of this object")
    resource_uris: List[StrictStr] = Field(description="URIs of Resources hosted at this Site.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "name", "description", "last_modified", "short_name", "operating_organization", "country_name", "locality_name", "state_or_province_name", "street_address", "unlocode", "altitude", "latitude", "longitude", "self_uri", "resource_uris"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Site from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "self_uri",
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if short_name (nullable) is None
        # and model_fields_set contains the field
        if self.short_name is None and "short_name" in self.model_fields_set:
            _dict['short_name'] = None

        # set to None if operating_organization (nullable) is None
        # and model_fields_set contains the field
        if self.operating_organization is None and "operating_organization" in self.model_fields_set:
            _dict['operating_organization'] = None

        # set to None if country_name (nullable) is None
        # and model_fields_set contains the field
        if self.country_name is None and "country_name" in self.model_fields_set:
            _dict['country_name'] = None

        # set to None if locality_name (nullable) is None
        # and model_fields_set contains the field
        if self.locality_name is None and "locality_name" in self.model_fields_set:
            _dict['locality_name'] = None

        # set to None if state_or_province_name (nullable) is None
        # and model_fields_set contains the field
        if self.state_or_province_name is None and "state_or_province_name" in self.model_fields_set:
            _dict['state_or_province_name'] = None

        # set to None if street_address (nullable) is None
        # and model_fields_set contains the field
        if self.street_address is None and "street_address" in self.model_fields_set:
            _dict['street_address'] = None

        # set to None if unlocode (nullable) is None
        # and model_fields_set contains the field
        if self.unlocode is None and "unlocode" in self.model_fields_set:
            _dict['unlocode'] = None

        # set to None if altitude (nullable) is None
        # and model_fields_set contains the field
        if self.altitude is None and "altitude" in self.model_fields_set:
            _dict['altitude'] = None

        # set to None if latitude (nullable) is None
        # and model_fields_set contains the field
        if self.latitude is None and "latitude" in self.model_fields_set:
            _dict['latitude'] = None

        # set to None if longitude (nullable) is None
        # and model_fields_set contains the field
        if self.longitude is None and "longitude" in self.model_fields_set:
            _dict['longitude'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Site from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "last_modified": obj.get("last_modified"),
            "short_name": obj.get("short_name"),
            "operating_organization": obj.get("operating_organization"),
            "country_name": obj.get("country_name"),
            "locality_name": obj.get("locality_name"),
            "state_or_province_name": obj.get("state_or_province_name"),
            "street_address": obj.get("street_address"),
            "unlocode": obj.get("unlocode"),
            "altitude": obj.get("altitude"),
            "latitude": obj.get("latitude"),
            "longitude": obj.get("longitude"),
            "self_uri": obj.get("self_uri"),
            "resource_uris": obj.get("resource_uris")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


